"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSettingsCrud = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _fields = require("@commodo/fields");
var _validation = require("@webiny/validation");
/**
 * Package @commodo/fields does not have types.
 */
// @ts-ignore

const CreateDataModel = (0, _fields.withFields)({
  uploadMinFileSize: (0, _fields.number)({
    value: 0,
    validation: _validation.validation.create("gte:0")
  }),
  uploadMaxFileSize: (0, _fields.number)({
    value: 10737418240
  }),
  srcPrefix: (0, _fields.onSet)(value => {
    // Make sure srcPrefix always ends with forward slash.
    if (typeof value === "string") {
      return value.endsWith("/") ? value : value + "/";
    }
    return value;
  })((0, _fields.string)({
    value: "/files/"
  }))
})();
const UpdateDataModel = (0, _fields.withFields)({
  uploadMinFileSize: (0, _fields.number)({
    validation: _validation.validation.create("gte:0")
  }),
  uploadMaxFileSize: (0, _fields.number)(),
  srcPrefix: (0, _fields.onSet)(value => {
    // Make sure srcPrefix always ends with forward slash.
    if (typeof value === "string") {
      return value.endsWith("/") ? value : value + "/";
    }
    return value;
  })((0, _fields.string)())
})();
const createSettingsCrud = ({
  storageOperations,
  getTenantId
}) => {
  return {
    async getSettings() {
      return storageOperations.settings.get({
        tenant: getTenantId()
      });
    },
    async createSettings(data) {
      const settings = new CreateDataModel().populate(data);
      await settings.validate();
      const settingsData = await settings.toJSON();
      return storageOperations.settings.create({
        data: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, settingsData), {}, {
          tenant: getTenantId()
        })
      });
    },
    async updateSettings(data) {
      const updatedValue = new UpdateDataModel().populate(data);
      await updatedValue.validate();
      const existingSettings = await storageOperations.settings.get({
        tenant: getTenantId()
      });
      const updatedSettings = await updatedValue.toJSON({
        onlyDirty: true
      });
      return storageOperations.settings.update({
        original: existingSettings,
        data: (0, _objectSpread2.default)((0, _objectSpread2.default)((0, _objectSpread2.default)({}, existingSettings), updatedSettings), {}, {
          tenant: getTenantId()
        })
      });
    },
    async deleteSettings() {
      await storageOperations.settings.delete({
        tenant: getTenantId()
      });
      return true;
    }
  };
};
exports.createSettingsCrud = createSettingsCrud;