"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _sanitizeImageTransformations = _interopRequireDefault(require("./sanitizeImageTransformations"));
var _utils = require("../../utils");
var newUtils = _interopRequireWildcard(require("../utils"));
var legacyUtils = _interopRequireWildcard(require("../legacyUtils"));
const IMAGE_TRANSFORMER_FUNCTION = process.env.IMAGE_TRANSFORMER_FUNCTION;
const callImageTransformerLambda = async ({
  key,
  transformations,
  context
}) => {
  return await context.handlerClient.invoke({
    name: IMAGE_TRANSFORMER_FUNCTION,
    payload: {
      body: {
        key,
        transformations
      }
    }
  });
};
var _default = {
  canProcess: ({
    file
  }) => {
    const utils = file.name.includes("/") ? newUtils : legacyUtils;
    return utils.SUPPORTED_IMAGES.includes(file.extension);
  },
  async process({
    s3,
    file,
    options,
    context
  }) {
    // Loaders must return {object, params} object.
    let objectParams;
    const utils = file.name.includes("/") ? newUtils : legacyUtils;
    const transformations = (0, _sanitizeImageTransformations.default)(options);
    if (transformations && utils.SUPPORTED_TRANSFORMABLE_IMAGES.includes(file.extension)) {
      objectParams = (0, _utils.getObjectParams)(utils.getImageKey({
        key: file.name,
        transformations
      }));
      try {
        return {
          object: await s3.getObject(objectParams).promise(),
          params: objectParams
        };
      } catch (e) {
        const imageTransformerLambdaResponse = await callImageTransformerLambda({
          key: file.name,
          transformations,
          context
        });
        if (imageTransformerLambdaResponse.error) {
          throw Error(imageTransformerLambdaResponse.message);
        }
        return {
          object: await s3.getObject(objectParams).promise(),
          params: objectParams
        };
      }
    }
    objectParams = (0, _utils.getObjectParams)(utils.getImageKey({
      key: file.name
    }));
    try {
      return {
        object: await s3.getObject(objectParams).promise(),
        params: objectParams
      };
    } catch (e) {
      const imageTransformerLambdaResponse = await callImageTransformerLambda({
        key: file.name,
        context
      });
      if (imageTransformerLambdaResponse.error) {
        throw Error(imageTransformerLambdaResponse.message);
      }
      return {
        object: await s3.getObject(objectParams).promise(),
        params: objectParams
      };
    }
  }
};
exports.default = _default;